@@ -12,6 +12,7 @@ from fhir_cli import (
     DBT_META_TABLE,
     DBT_SCHEMA,
     FHIR_COLUMN_NAME,
+    FHIR_DBT_SCHEMA,
     PACKAGE_PATH,
     POSTGRES_DB,
     POSTGRES_HOST,
@@ -190,7 +191,7 @@ class Cli:
             user=POSTGRES_USER,
             password=POSTGRES_PASSWORD,
             cursor_factory=RealDictCursor,
-            options=f"-c search_path={DBT_SCHEMA}",
+            options=f"-c search_path={FHIR_DBT_SCHEMA}",
         )
         cursor = conn.cursor(name="curname")
         try:
